# Security Policy

## Supported Versions

We currently only support the latest versions of the software with security
updates. I.e., we will not backport new security updates to old versions.

## Reporting a Vulnerability

If you believe you have found a security vulnerability in the repository, we
encourage you to let us know right away. We will investigate all legitimate
reports and do our best to quickly fix the problem.

Please report security issues to the Issue Tracker or Security Advisories.
